%define anolis_release 3

%{!?python3_sitearch:%global python3_sitearch %(%{__python3} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

%if %{with python3}
%global configure_with_python3 yes
%else
%global configure_with_python3 no
%endif

# Additional configure options:
%global with_pythons  --with-python3=%{?configure_with_python3}

Summary: An utility for manipulating storage encryption keys and passphrases
Name: volume_key
Version: 0.3.12
Release: %{anolis_release}%{?dist}
License: GPLv2 and (MPLv1.1 or GPLv2)
Group: Applications/System
URL: https://pagure.io/%{name}/
Requires: %{name}-libs = %{version}-%{release}

Source0: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.xz
BuildRequires: gcc
BuildRequires: nss-tools
BuildRequires: gpgme-devel, libblkid-devel, nss-devel, python3-devel
BuildRequires: cryptsetup-devel, gettext-devel, glib2-devel, /usr/bin/gpg2

%description
Volume_key is an encryption key used to protect the volume of a storage
device. It is a cryptographic key that is used to encrypt and decrypt
data on a storage device such as a hard disk, USB drive, or other storage
devices. It is also known as a disk encryption key or a disk password.

When a volume key is applied to a storage device, it scrambles the data
on the device so that it cannot be read or accessed without the key.
The key is used to lock and unlock the device and is required each time
the device is accessed.

Volume keys are usually generated using a secure algorithm that generates
a random key that is impossible to guess or predict. These keys are then
securely stored on the device or in a secure location to ensure that
they cannot be compromised or lost.

Volume keys are essential for protecting sensitive data and ensuring that
it cannot be accessed by unauthorized users. They are commonly used in
disk encryption software such as BitLocker and FileVault to encrypt and
protect data on Windows and Mac operating systems.

In summary, volume keys are encryption keys used to protect the volume of a
storage device. They are generated using a secure algorithm, are required to
lock and unlock the device, and are essential for protecting sensitive data.

%package devel
Summary: A library for manipulating storage encryption keys and passphrases
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}

%description devel
This package contains header files for developers.

%package libs
Summary: A library for manipulating storage encryption keys and passphrases
Group: System Environment/Libraries
Requires: /usr/bin/gpg2

%description libs
This package provides libs for developers.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%if %{with python3}
%package -n python3-%{name}
%{?python_provide:%python_provide python3-%{name}}
Summary: Python 3 bindings for lib%{name}
Group: System Environment/Libraries
Requires: %{name}-libs = %{version}-%{release}

%description -n python3-%{name}
python3-volume_key is a Python3 binding library for the libvolume-key library.
libvolume-key is a library for manipulating encrypted storage volumes, including
handling of encryption keys and passphrase verification.

With python3-volume_key, developers can use Python to access the libvolume-key
API and perform tasks such as unlocking encrypted volumes, creating new encrypted
volumes, and managing encryption keys.

python3-volume_key provides a high-level, object-oriented interface to libvolume-key,
making it easy to use for Python developers who want to work with encrypted storage
volumes.
%endif

%prep
%setup -q

%build
%configure %{?with_pythons}
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL='install -p'

# Remove libtool archive
find %{buildroot} -type f -name "*.la" -delete

%check
make check || { \
echo "======================== ./test-suite.log ========================"; \
cat ./test-suite.log; \
echo "=================================================================="; \
exit 1; \
}

%find_lang %{name}

%files
%{_bindir}/%{name}
%{_mandir}/man8/%{name}.8*

%files devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so

%files libs -f %{name}.lang
%doc COPYING
%{_libdir}/lib%{name}.so.*

%if %{with python3}
%files -n python3-%{name}
%{python3_sitearch}/_%{name}.so
%{python3_sitearch}/%{name}.py*
%{python3_sitearch}/__pycache__/%{name}.*
%endif

%files doc
%doc README contrib AUTHORS ChangeLog NEWS

%changelog
* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 0.3.12-3
- Update the description

* Sun Oct 09 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.3.12-2
- add doc package

* Fri Mar 11 2022 Renbo <rb01097748@alibaba-inc.com> - 0.3.12-1 
- Init for Anolis OS 23
